<?php
/**
 * Customizer Control: wp-moose-select
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( class_exists( 'Moose_Customize_Control' ) && ! class_exists( 'Moose_Select_Customize_Control' ) ) {
	/**
	 * Select Control.
	 */
	class Moose_Select_Customize_Control extends Moose_Customize_Control {
		/**
		 * Set the control type.
		 *
		 * @var string $type
		 */
		public $type = 'wp-moose-select';

		/**
		 * Controls of each option
		 *
		 * @var array
		 */
		public $subcontrols;

		/**
		 * Toggle subcontrols when control ready.
		 *
		 * @var bool
		 */
		public $should_init;

		/**
		 * Refresh the parameters passed to the JavaScript via JSON.
		 *
		 * @see WP_Customize_Control::to_json()
		 */
		public function to_json() {
			parent::to_json();

			$this->json['subcontrols'] = $this->subcontrols;
			$this->json['should_init'] = $this->should_init;
		}

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @return void
		 * @see WP_Customize_Control::print_template()
		 * @since 1.0.0
		 */
		public function content_template() {
			?>
            <# if ( ! data.choices ) { return; } #>

            <label>
				<?php $this->label_template(); ?>

                <select {{{ data.link }}}>
                    <# _.each( data.choices, function( label, choice ) {
                    var selected = choice === data.value ? 'selected="selected"' : '';
                    #>
                    <option value="{{ choice }}" {{selected}}>{{ label }}</option>
                    <# } ) #>
                </select>
            </label>
			<?php
		}
	}
}
