<?php
if ( ! function_exists( 'wp_moose_woo_scripts_styles' ) ) {
	/**
	 * enqueue our scripts and styles for woocommerce
	 */
	function wp_moose_woo_scripts_styles() {
		// registers scripts and stylesheets for woocommerce
		wp_register_style( 'wp-moose-woocommerce', wp_moose_asset_resolve( 'css/woocommerce' . wp_moose_get_stylesheet_suffix() . '.css' ), array(), WP_MOOSE_VERSION );

		// enqueue assets for woocommerce
		wp_enqueue_style( 'wp-moose-woocommerce' );

		// dequeue default style
		wp_dequeue_style( 'wp-moose-style' );
	}
}
add_action( 'wp_enqueue_scripts', 'wp_moose_woo_scripts_styles', 20 );

if ( ! function_exists( 'wp_moose_woo_setup' ) ) {
	/**
	 * WooCommerce setup.
	 */
	function wp_moose_woo_setup() {
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}
}
add_action( 'after_setup_theme', 'wp_moose_woo_setup' );

/**
 * Main content
 */

if ( ! function_exists( 'wp_moose_woo_before_content' ) ) {
	/**
	 * Wrap woocommerce content - start
	 */
	function wp_moose_woo_before_content() {

		$layout    = get_wp_moose_sidebar_layout( 'store' );
		$wrap_clsx = array(
			'wp-moose-woo-container container mx-auto py-half-gutter lg:flex',
			'no-sidebar'          => $layout === 'no-sidebar',
			'lg:flex-row'         => $layout === 'right-sidebar',
			'lg:flex-row-reverse' => $layout === 'left-sidebar',
		);
		?>
    <div class="<?php wp_moose_clsx_echo( $wrap_clsx ); ?>">
        <div class="flex-grow p-half-gutter">
    <div id="content"
         class="rounded-md p-gutter form-controls form-default form-primary <?php echo get_wp_moose_page_container_style(); ?>">
		<?php
	}
}
add_action( 'woocommerce_before_main_content', 'wp_moose_woo_before_content', 5 );

if ( ! function_exists( 'wp_moose_woo_after_content' ) ) {
	/**
	 * Wrap woocommerce content - end
	 */
	function wp_moose_woo_after_content() {
		echo '</div></div>';

		/**
		 * Hook - wp_moose_action_sidebar.
		 *
		 * @hooked wp_moose_add_primary_sidebar   - 10;
		 */
		do_action( 'wp_moose_action_sidebar', get_wp_moose_sidebar_layout( 'store' ) );

		echo '</div>';
	}
}
add_action( 'woocommerce_after_main_content', 'wp_moose_woo_after_content', 50 );

// Remove Default Sidebar
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
